from salt import exceptions

def run(name, force):
    # setup arguments
    ret = {
        'name': name,
        'force': force,
        'result': False,
        'changes': {},
        'comment': ''
    }


    # call the check
    result = __salt__['influx_monitoring.check']()


    # handle check results
    if not result:
        ret['result'] = True
        ret['comment'] = 'Monitoring is already disabled'
        return ret


    # indicate check results if running under test
    if __opts__['test']:
        ret['result'] = None
        ret['comment'] = 'Monitoring would be disabled'
        ret['changes'] = result
        return ret


    # perform action if not under test
    try:
        result = __salt__['influx_monitoring.disable'](force)
    except exceptions.CommandExecutionError:
        result = False


    # verify final state
    ret['changes'] = __salt__['influx_monitoring.check']()


    # indicate if the state succeeded
    if ret['changes']:
        ret['comment'] = 'Failed to disable monitoring'
    else:
        ret['result'] = True
        ret['comment'] = 'Monitoring was successfully disabled'


    # return ultimate results
    return ret

